| Title: | Air Pollution Tolerance Index (APTI) Calculator |
|---|---|
| Description: | It calculates the Air Pollution Tolerance Index (APTI) of plant species using biochemical parameters such as chlorophyll content, leaf extract pH, relative water content, and ascorbic acid content. It helps in identifying tolerant species for greenbelt development and pollution mitigation studies. It includes a 'shiny' app for interactive APTI calculation and visualisation. For method details see, Sahu et al. (2020).<DOI:10.1007/s42452-020-3120-6>. |
| Authors: | Nobin Chandra Paul [aut, cre, cph], Rupali Singh [aut, cph], Sangram B Chavan [aut, cph], Navyasree Ponnaganti [aut, cph], K. Sammi Reddy [aut, cph] |
| Maintainer: | Nobin Chandra Paul <[email protected]> |
| License: | GPL (>= 2.0) |
| Version: | 0.1.1 |
| Built: | 2026-06-01 10:18:34 UTC |
| Source: | https://github.com/cran/APTIcalc |
This function calculates the Air Pollution Tolerance Index (APTI) using plant biochemical parameters: ascorbic acid (A), total chlorophyll (T),leaf extract pH (P), and relative water content (R) and classifies plants into tolerance categories based on biochemical parameters.APTI helps assess plant tolerance to air pollution.
comp_apti(A, TC, P, R)comp_apti(A, TC, P, R)
A |
Numeric vector of Ascorbic acid content, unit is mg per g dry weight |
TC |
Numeric vector of Total chlorophyll content, unit is mg per g dry weight |
P |
Numeric vector of Leaf extract pH. |
R |
Numeric vector of Relative water content, in percentage |
This function returns original parameters, computed APTI values, and tolerance categories: "Sensitive", "Intermediate", or "Tolerant".
A data frame containing APTI values and tolerance category:
Calculated index value.
Plant tolerance class: Sensitive (<12), Intermediate (12–20), or Tolerant (>20).
1. Singh, S.K. and Rao, D.N. (1983) Evaluation of Plants for Their Tolerance to Air Pollution. Symposium on Air Pollution Control, 1983, 218-224.
2. Thakar, B. K., & Mishra, P. C. (2010). Dust collection potential and air pollution tolerance index of tree vegetation around Vedanta Aluminium Limited, Jharsuguda. The Bioscan, 3, 603-612.
3. Sahu, C., Basti, S., & Sahu, S. K. (2020). Air pollution tolerance index (APTI) and expected performance index (EPI) of trees in Sambalpur town of India. SN Applied Sciences, 2(8), 1327.
A <- c(4.91, 5.00, 4.90) TC <- c(9.987, 8.881, 8.202) P <- c(3.927, 3.872, 4.168) R <- c(46.71, 55.11, 52.01) comp_apti(A, TC, P, R)A <- c(4.91, 5.00, 4.90) TC <- c(9.987, 8.881, 8.202) P <- c(3.927, 3.872, 4.168) R <- c(46.71, 55.11, 52.01) comp_apti(A, TC, P, R)
Launches a 'Shiny' app for interactive APTI calculation and visualization.
run_apti_app()run_apti_app()
Launches a Shiny application.
if (interactive()) { run_apti_app() }if (interactive()) { run_apti_app() }
A dataset containing biochemical parameters used to compute APTI.
sample_datasample_data
A data frame with 15 rows and 4 variables:
Ascorbic acid content (mg/g)
Total chlorophyll content (mg/g)
Leaf extract pH
Relative water content (%)
Manually entered for demonstration